job "repo" {

  datacenters = ["dc1"]
  region      = "global"


  group "web" {

    count = 1

    network {
      mode = "bridge"
    }

    volume "repo" {
      type            = "csi"
      source          = "repo"
      access_mode     = "multi-node-single-writer"
      attachment_mode = "file-system"
      read_only       = true
    }

    service {
      name = "repo-web"
      port = 8080

      connect {
        sidecar_service {
        }
        sidecar_task {

          logs {
            disabled = false
          }

          config {
            args = [
              "-c",
              "${NOMAD_SECRETS_DIR}/envoy_bootstrap.json",
              "-l",
              "${meta.connect.log_level}",
              "--concurrency",
              "${meta.connect.proxy_concurrency}",
              "--disable-hot-restart"
            ]
          }

          resources {
            cpu    = 50
            memory = 64
          }

        }
      }


      tags = [

        "traefik.enable=true",
        "traefik.http.routers.repo.entrypoints=https",
        "traefik.http.routers.repo.rule=Host(`repo.example.org`)",
        "traefik.http.routers.repo.middlewares=security-headers@file,rate-limit-std@file,forward-proto@file,inflight-std@file,hsts@file,compression@file,autodetect@file",

      ]
    }

    task "nginx" {
      driver = "docker"
      user   = 2022

      config {
        image           = "nginxinc/nginx-unprivileged:alpine"
        pids_limit      = 50
        readonly_rootfs = true
        volumes = [
          "local/nginx.conf:/etc/nginx/conf.d/default.conf"
        ]
        mount {
          type   = "tmpfs"
          target = "/tmp"
          tmpfs_options {
            size = 3000000
          }
        }

      }



      # Use a template block instead of env {} so we can fetch values from vault
      template {
        data        = <<_EOT
LANG=fr_FR.utf8
TZ=Europe/Paris
_EOT
        destination = "secrets/.env"
        perms       = 400
        env         = true
      }


      template {
        data        = <<_EOF
error_log /dev/stderr debug;
server {
  listen 127.0.0.1:8080;
  server_name _;
  server_tokens off;
  set_real_ip_from 127.0.0.1;
  real_ip_header X-Forwarded-For;
  real_ip_recursive on;
  root /data/repo;
  autoindex on;
  autoindex_localtime on;
  autoindex_exact_size off;
}

_EOF
        destination = "local/nginx.conf"
      }

      volume_mount {
        volume      = "repo"
        destination = "/data"
        read_only   = true
      }


      resources {
        cpu    = 20
        memory = 40
      }

    }
  }

  group "rsync" {

    network {
      mode = "bridge"
      port "ssh" {}
    }

    volume "repo" {
      type            = "csi"
      source          = "repo"
      attachment_mode = "file-system"
      access_mode     = "multi-node-single-writer"
    }

    volume "ssh" {
      type            = "csi"
      source          = "repo-ssh"
      attachment_mode = "file-system"
      access_mode     = "single-node-writer"
    }

    service {
      name = "repo-rsync"
      port = "ssh"
      tags = [

        "traefik.enable=true",
        "traefik.consulcatalog.connect=false",
        "traefik.tcp.routers.repo-rsync.entrypoints=repo-rsync",
        "traefik.tcp.routers.repo-rsync.rule=HostSNI(`*`)",

      ]
    }

    task "rsync-ssh" {
      driver = "docker"

      config {
        image           = "danielberteaud/rsync-ssh:24.5-1"
        pids_limit      = 100
        readonly_rootfs = true
        mount {
          type   = "tmpfs"
          target = "/tmp"
          tmpfs_options {
            size = 3000000
          }
        }

      }

      env {
        SSHD_PORT = "${NOMAD_PORT_ssh}"

        LANG = "fr_FR.utf8"
        TZ   = "Europe/Paris"

      }

      vault {
        policies     = ["repo"]
        env          = false
        disable_file = true
      }

      template {
        data        = <<-_EOF
          {{ with secret "kv/service/repo" }}
          {{- range $idx, $key := .Data.data.ssh_keys | split "," -}}
          SSH_AUTH_KEY_{{ $idx }}={{ $key }}
          {{ end }}{{ end }}
        _EOF
        destination = "secrets/env"
        env         = true
      }

      volume_mount {
        volume      = "repo"
        destination = "/data"
      }

      volume_mount {
        volume      = "ssh"
        destination = "/config"
      }


      resources {
        cpu        = 20
        memory     = 64
        memory_max = 128
      }

    }
  }
}

# vim: syntax=hcl
